@@ -1,5 +1,6 @@
+use criterion::Criterion;
 use criterion::criterion_group;
-use criterion::{Criterion, black_box};
+use std::hint::black_box;
 use television::channels::prototypes::ChannelPrototype;
 use television::config::layers::ConfigLayers;
 use television::{
