@@ -23,12 +23,7 @@ pub struct Cli {
 
     /// The working directory to start the application in.
     ///
-    /// This flag works identically in both channel mode and ad-hoc mode.
-    ///
-    /// This can be used to specify a different working directory for the
-    /// application to start in. This is useful when the application is
-    /// started from a different directory than the one the user wants to
-    /// interact with.
+    /// Defaults to the current directory.
     #[arg(value_name = "PATH", index = 2, verbatim_doc_comment)]
     pub working_directory: Option<String>,
 
@@ -233,6 +228,18 @@ pub struct Cli {
     )]
     pub preview_padding: Option<String>,
 
+    /// Enables preview panel word wrap.
+    ///
+    /// Example: `--preview-word-wrap`
+    #[arg(
+        long,
+        default_value = "false",
+        verbatim_doc_comment,
+        conflicts_with = "no_preview",
+        help_heading = "Preview"
+    )]
+    pub preview_word_wrap: bool,
+
     /// Hide preview panel scrollbar.
     #[arg(
         long,
@@ -296,9 +303,19 @@ pub struct Cli {
     )]
     pub input_prompt: Option<String>,
 
-    /// Sets the input panel border type.
+    /// Input bar position.
     ///
-    /// Available options are: `none`, `plain`, `rounded`, `thick`.
+    /// Sets whether the input panel is shown at the top or bottom of the UI.
+    #[arg(
+        long,
+        value_enum,
+        value_name = "INPUT_POSITION",
+        verbatim_doc_comment,
+        help_heading = "Input"
+    )]
+    pub input_position: Option<InputPosition>,
+
+    /// Sets the input panel border type.
     #[arg(long, value_enum, verbatim_doc_comment, help_heading = "Input")]
     pub input_border: Option<BorderType>,
 
@@ -338,8 +355,6 @@ pub struct Cli {
     pub show_status_bar: bool,
 
     /// Sets the results panel border type.
-    ///
-    /// Available options are: `none`, `plain`, `rounded`, `thick`.
     #[arg(long, value_enum, verbatim_doc_comment, help_heading = "UI")]
     pub results_border: Option<BorderType>,
 
@@ -360,8 +375,6 @@ pub struct Cli {
     ///
     /// When a channel is specified: Overrides the layout/orientation defined in the channel prototype.
     /// When no channel is specified: Sets the layout orientation for the ad-hoc channel.
-    ///
-    /// Options are "landscape" or "portrait".
     #[arg(long, value_enum, verbatim_doc_comment, help_heading = "UI")]
     pub layout: Option<LayoutOrientation>,
 
@@ -673,6 +686,12 @@ pub enum LayoutOrientation {
     Portrait,
 }
 
+#[derive(Debug, Clone, Copy, PartialEq, ValueEnum)]
+pub enum InputPosition {
+    Top,
+    Bottom,
+}
+
 #[derive(Debug, Clone, Copy, PartialEq, ValueEnum)]
 pub enum BorderType {
     None,
