@@ -1,15 +1,14 @@
 use crate::{
     action::{Action, Actions},
-    config::KeyBindings,
+    config::Keybindings,
 };
 
 /// Extract keys for a single action
 pub fn find_keys_for_single_action(
-    keybindings: &KeyBindings,
+    keybindings: &Keybindings,
     target_action: &Action,
 ) -> Vec<String> {
     keybindings
-        .inner
         .iter()
         .filter_map(|(key, actions)| {
             // Check if this actions contains the target action
@@ -24,10 +23,8 @@ pub fn find_keys_for_single_action(
 
 /// Remove all keybindings for a specific action from `KeyBindings`
 pub fn remove_action_bindings(
-    keybindings: &mut KeyBindings,
+    keybindings: &mut Keybindings,
     target_action: &Actions,
 ) {
-    keybindings
-        .inner
-        .retain(|_, action| action != target_action);
+    keybindings.retain(|_, action| action != target_action);
 }
