@@ -145,6 +145,30 @@ fn test_preview_size_with_preview_command() {
     PtyTester::assert_exit_ok(&mut child, DEFAULT_DELAY);
 }
 
+/// Tests that --preview-word-wrap enables preview panel word wrapping.
+#[test]
+fn test_preview_word_wrap_with_preview_command() {
+    let mut tester = PtyTester::new();
+
+    // This sets the preview panel to 10% of screen width
+    let cmd = tv_local_config_and_cable_with_args(&[
+        "files",
+        "--preview-word-wrap",
+        "-p",
+        "echo 'Hello world'",
+        "--preview-size",
+        "10",
+    ]);
+    let mut child = tester.spawn_command_tui(cmd);
+
+    // Verify the preview panel is active
+    tester.assert_tui_frame_contains("│ Hello    │");
+
+    // Send Ctrl+C to exit
+    tester.send(&ctrl('c'));
+    PtyTester::assert_exit_ok(&mut child, DEFAULT_DELAY);
+}
+
 /// Tests that --no-preview completely disables the preview panel.
 #[test]
 fn test_no_preview_disables_preview_panel() {
